from storekit.models import Receipt

import pytest


@pytest.mark.django_db
def test_new_data_save_true(read_json, first_in_app):
    receipt = Receipt.parser(read_json['receipt'], in_app=first_in_app)

    assert receipt is not None


@pytest.mark.django_db
def test_new_data_save_false(read_json, first_in_app):
    receipt = Receipt.parser(read_json['receipt'], in_app=first_in_app, is_save=False)

    assert receipt is not None


@pytest.mark.django_db
def test_str(read_json, first_in_app):
    receipt = Receipt.parser(read_json['receipt'], in_app=first_in_app)

    assert str(receipt) == '[{}] {}: {}'.format(receipt.receipt_type, receipt.bundle_id, receipt.application_version)


@pytest.mark.django_db
def test_repr(read_json, first_in_app):
    receipt = Receipt.parser(read_json['receipt'], in_app=first_in_app)

    assert repr(receipt) == '<ID: {}>: "{}"'.format(receipt.id, receipt.__class__.__name__)



from .testing import JSON_FILE_PATH

import json
import pytest


@pytest.fixture(scope='class')
def read_json():
    with open(JSON_FILE_PATH, 'r') as f:
        return json.loads(f.read())


@pytest.fixture(scope='class')
def bundle_id():
    return 'com.example.test'



from storekit.appstore import AppStoreValidator
from storekit.errors import AppValidationError

import copy
import pytest


def test_use_sandbox(bundle_id):
    validator = AppStoreValidator(bundle_id, True)

    assert validator.url == 'https://sandbox.itunes.apple.com/verifyReceipt'


def test_not_use(bundle_id):
    validator = AppStoreValidator(bundle_id, False)

    assert validator.url == 'https://buy.itunes.apple.com/verifyReceipt'


@pytest.mark.django_db
def test_use_password(read_json, bundle_id, requests_mock):
    validator = AppStoreValidator(bundle_id)
    requests_mock.post(validator.url, json=read_json)
    result = validator.validate('', password='test_password')

    assert result


@pytest.mark.django_db
def test_validate_success(read_json, bundle_id, requests_mock):
    validator = AppStoreValidator(bundle_id)
    requests_mock.post(validator.url, json=read_json)
    result = validator.validate('')

    assert result


def test_validate_status_error(read_json, bundle_id, requests_mock):
    validator = AppStoreValidator(bundle_id)
    json_data = copy.copy(read_json)
    json_data['status'] = 1
    requests_mock.post(validator.url, json=json_data)

    with pytest.raises(AppValidationError):
        _ = validator.validate('')


def test_mismatch_bundle_id(read_json, requests_mock):
    validator = AppStoreValidator('com.example.wrong')
    requests_mock.post(validator.url, json=read_json)

    with pytest.raises(AppValidationError):
        _ = validator.validate('')



from storekit.models import InApp

import pytest


@pytest.mark.django_db
def test_new_data_save_true(first_in_app):
    in_app = InApp.parser(first_in_app)

    assert in_app is not None


def test_new_data_save_false(first_in_app):
    in_app = InApp.parser(first_in_app, is_save=False)

    assert in_app is not None


@pytest.mark.django_db
def test_str(first_in_app):
    in_app = InApp.parser(first_in_app)

    assert str(in_app) == '{}: {}'.format(in_app.product_id, in_app.quantity)


@pytest.mark.django_db
def test_repr(first_in_app):
    in_app = InApp.parser(first_in_app)

    assert repr(in_app) == '{} <ID: {}>: "{}"'.format(in_app.product_id, in_app.id, in_app.__class__.__name__)



import os.path

SECRET_KEY = 'secret_key_for_testing'

BASE_DIR = os.path.dirname(os.path.dirname(__file__))

DEBUG = True

INSTALLED_APPS = [
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'storekit',
    'tests'
]

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'test_db.sqlite'),
    }
}

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

STOREKIT_PURCHASED_SECRET = 'storekit_purchased_secret'
STOREKIT_APP_BUNDLE_ID = 'com.example.test'



from storekit.models import Response

import pytest


@pytest.mark.django_db
def test_new_data_save_true(read_json, first_in_app):
    response = Response.parser(read_json, in_app=first_in_app)

    assert response is not None


@pytest.mark.django_db
def test_new_data_save_false(read_json, first_in_app):
    response = Response.parser(read_json, in_app=first_in_app, is_save=False)

    assert response is not None


@pytest.mark.django_db
def test_str(read_json, first_in_app):
    response = Response.parser(read_json, in_app=first_in_app)

    assert str(response) == 'Response: {}'.format(response.environment)


@pytest.mark.django_db
def test_repr(read_json, first_in_app):
    response = Response.parser(read_json, in_app=first_in_app)

    assert repr(response) == '<ID: {}>: "{}"'.format(response.id, response.__class__.__name__)



from setuptools import setup


def readlist(filename):
    rows = open(filename).read().split('\n')
    rows = [x.strip() for x in rows if x.strip()]
    return list(rows)


setup(
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    download_url='https://github.com/nnsnodnb/django-ios-storekit/tarball/master',
    include_package_data=True,
    package_data={
        '': [
                'README.rst',
                'requirements.txt',
                'requirements-test.txt'
            ]
    },
    install_requires=readlist('requirements.txt'),
    test_suite='runtests.run_tests',
    tests_require=readlist('requirements-test.txt')
)



from django.db.models import BigIntegerField
from django.utils.translation import gettext_lazy as _


class PositiveBigIntegerField(BigIntegerField):

    empty_strings_allowed = False
    description = _('Big (8 byte) positive integer')

    def db_type(self, connection):
        return 'bigint UNSIGNED'

    def get_internal_type(self):
        return 'PositiveSmallIntegerField'

    def formfield(self, **kwargs):
        defaults = {
            'min_value': 0,
            'max_value': BigIntegerField.MAX_BIGINT
        }
        defaults.update(kwargs)
        return super(PositiveBigIntegerField, self).formfield(**defaults)
